benchmark

Function benchmark 

pub fn benchmark(args: &BenchmarkArgs) -> Result<(), Box<dyn Error>>
Run compression benchmarks.

Errors

Returns an error if the data pattern or algorithm name is not recognised, or if the underlying trueno_zram_core benchmark fails.